@@ -10,12 +10,14 @@ from enum import Enum
 from enum import StrEnum
 from types import UnionType
 from typing import ClassVar
-from typing import Optional, Type, Any, Union
+from typing import Optional, Type, Any
 
 from apispec import APISpec
 from http_tools import Answer
 from init_helpers.dict_to_dataclass import NoValue
 
+from .extras import DataclassProtocol
+
 logger = logging.getLogger(__name__)
 
 
@@ -139,16 +141,22 @@ class OpenApiWrapper:
         self.config = config
         self.context = context
         self.endpoints = []
+        self.dataclass_type_to_name: dict[type[DataclassProtocol] | UnionType, str] = {}
 
     def register_endpoint(self, endpoint: Endpoint) -> None:
         self.endpoints.append(endpoint)
 
+    def register_dataclass(self, dataclass_type: type[DataclassProtocol], name: str) -> None:
+        self.dataclass_type_to_name[dataclass_type] = name
+
     def get_spec_dict(self) -> dict:
         spec = APISpec(
             title=f"{self.context.company}:{self.context.project_group}:{self.context.project_name}",
             version=self.version,
             openapi_version="3.1.0"
         )
+        for dataclass_type in self.dataclass_type_to_name:
+            self._add_schema_to_spec(spec, dataclass_type)
         for endpoint in self.endpoints:
             self._add_endpoint_to_spec(spec, endpoint)
         return spec.to_dict()
@@ -230,7 +238,7 @@ class OpenApiWrapper:
                 if field_.repr:
                     description["properties"][field_.name] = self._add_schema_to_spec(spec, field_.type)
 
-            name = f"schema_{schema.__name__}"
+            name = self.dataclass_type_to_name.get(schema, f"schema_{schema.__name__}")
             logger.debug('schema: %s, %s, %s', name, schema, list(description["properties"]))
             spec.components.schema(component_id=name, component=description)
             return spec.components.get_ref("schema", name)
